*******************************************************
*******************************************************
******SOFTWARE USED: STATA 14**************************
*******************************************************

clear
set more off
cd "D:\Research\AAD-China"
import excel "C:\Users\Armenak\Dropbox\Tax Experiments China Zareh Zhixin\JEBO\Data.xlsx", sheet("data") firstrow

label variable ID "The fictitious ID of the taxpayer"
label variable date_paid2016 "The date 2016 property tax was paid on"
label variable date_paid2017 "The date 2017 property tax was paid on"
label variable date_paid2018 "The date 2018 property tax was paid on"
label variable date_taxstart "The starting date of the property tax for the current properties owned by a taxpayer"
label variable gender "The gender of the taxpayer"
label variable treatment "Treatment arms of the trial"
label variable experiment_start "The first day of the experiment"
label variable experiment_end "The last day of the experiment"


gen Days_paying_taxes_by_start=experiment_start-date_taxstart
gen Months_paying_taxes_by_start=Days_paying_taxes_by_start/30


***For understanding the behavior in the first 25 and 40 days

gen paid25days=0
replace paid25days=1 if date_paid2018<=mdy(10,11,2019)

gen paid40days=0
replace paid40days=1 if date_paid2018<=mdy(10,26,2019)



**********************************************************************************************************
*************************RANDOMIZATION CHECK**************************************************************
**********************************************************************************************************

                                         

**Randomization check before dropping the 37 observations

foreach var of varlist Age gender taxarrears_2018{
reg `var' i.treatment, robust 
testparm i.treatment
local pval = r(p)
}


**Dropping the observations that paid before the start of the experiment

drop if date_paid2018<experiment_start
replace Age=. if Age<18

su Age
return list
replace Age=r(mean) if Age==.


                                        ***************
										****Table 2****
										***************
										
***Randomization check after dropping 37 observations***

foreach var of varlist Age gender taxarrears_2018 Months_paying_taxes_by_start{
reg `var' i.treatment, robust 
testparm i.treatment
test 1.treatment=2.treatment
test 1.treatment=3.treatment
test 2.treatment=3.treatment
local pval = r(p)
}


*************************************************************************************
*********************TREATMENT EFFECT ANALYSIS***************************************
*************************************************************************************

gen paid_experiment=0
replace paid_experiment=1 if date_paid2018!=. 
ta paid_experiment

**counting those taxpayers who paid in LF after the last reminder sent 

count if paid_experiment==1 & date_paid2018>=mdy(10,11,2019) & date_paid2018<mdy(10,15,2019) & treatment==1 //6

gen never_paid2016=0

//tax starting in 2011 or later, but not later than Jan 2017 and the person did not make the payment. 
//if tax started on Jan 2017, no 2016 tax was paid

replace never_paid2016=1 if date_taxstart>mdy(7,1,2011) & date_taxstart<mdy(1,1,2017) & date_paid2016==.
ta never_paid2016

//tax starting in 2011 or later, but not later than Jan 2018 and the person did not make the 2017 payment. 
//if tax started on Jan 2018, no 2017 tax was paid

gen never_paid2017=0
replace never_paid2017=1 if date_taxstart>mdy(7,1,2011) & date_taxstart<mdy(1,1,2018) & date_paid2017==.

gen never_paid_before=0
replace never_paid_before=1 if never_paid2016==1 & never_paid2017==1

								
								**************
								***Figure 1***
								**************

cibar paid_experiment, over(treatment) bargap(10) barlabel(on)

**the remaining of the graph is edited manually
								
								*************
								***Table 3***
                                *************

regress paid_experiment i.treatment, robust 

outreg using Table3, se bdec(3) ctitle("",1) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 1: Treatment Effects Analysis)

test 1.treatment=2.treatment //LF vs MF
test 1.treatment=3.treatment //LF vs HF
test 2.treatment=3.treatment //MF vs HF

**Extracting the coefficients for the analysis of tax benefits 

gen t0=_b[_cons]
gen t1=_b[_cons]+_b[1.treatment]
gen t2=_b[_cons]+_b[2.treatment]
gen t3=_b[_cons]+_b[3.treatment]

gen coeff_welf=.

replace coeff_welf=t0 if treatment==0
replace coeff_welf=t1 if treatment==1
replace coeff_welf=t2 if treatment==2
replace coeff_welf=t3 if treatment==3

drop t0 t1 t2 t3

regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start, robust

outreg using Table3, se bdec(3) ctitle("",2) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 1: Treatment Effects Analysis) ///
merge

test 1.treatment=2.treatment 
test 1.treatment=3.treatment
test 2.treatment=3.treatment 


**Extracting the coefficients for the analysis of tax benefits 

gen t0b=0.039
gen t1b=0.039+_b[1.treatment]
gen t2b=0.039+_b[2.treatment]
gen t3b=0.039+_b[3.treatment]

gen coeff_welfb=.

replace coeff_welfb=t0b if treatment==0
replace coeff_welfb=t1b if treatment==1
replace coeff_welfb=t2b if treatment==2
replace coeff_welfb=t3b if treatment==3

drop t0b t1b t2b t3b

gen coeff_welfbr=round(coeff_welfb,0.001)


                                **************************************************
                                ***Footnote 11: Compliance in the first 25 days***
                                **************************************************
								
regress paid25days i.treatment, robust 

outreg using Table1_Rob25, se bdec(3) ctitle("",1) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 1a: Treatment Effects Analysis for the first 25 days)


test 1.treatment=2.treatment //LF vs MF
test 1.treatment=3.treatment //LF vs HF
test 2.treatment=3.treatment //MF vs HF

regress paid25days i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start, robust 

outreg using Table1_Rob25, se bdec(3) ctitle("",2) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 1a: Treatment Effects Analysis for the first 25 days) ///
merge


test 1.treatment=2.treatment //LF vs MF
test 1.treatment=3.treatment //LF vs HF
test 2.treatment=3.treatment //MF vs HF

                                **************************************************
                                ***Footnote 11: Compliance in the first 40 days***
                                **************************************************
								
regress paid40days i.treatment, robust 

outreg using Table1_Rob40, se bdec(3) ctitle("",1) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 1b: Treatment Effects Analysis for the first 40 days)


test 1.treatment=2.treatment //LF vs MF
test 1.treatment=3.treatment //LF vs HF
test 2.treatment=3.treatment //MF vs HF

regress paid40days i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start, robust 

outreg using Table1_Rob40, se bdec(3) ctitle("",2) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 1b: Treatment Effects Analysis for the first 40 days) ///
merge


test 1.treatment=2.treatment //LF vs MF
test 1.treatment=3.treatment //LF vs HF
test 2.treatment=3.treatment //MF vs HF


**********************************************************
**********TABLE 2:Heterogeneity Analysis******************
**********************************************************

*** Data Broken Down by Gender

regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start if gender==1, robust
outreg using Table2, se bdec(3) ctitle("",Male) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 2: Heterogeneity Analysis)

test 1.treatment=2.treatment
test 1.treatment=3.treatment
test 2.treatment=3.treatment


regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start if gender==0, robust //all treatments are significantly different from the control group
outreg using Table2, se bdec(3) ctitle("",Female) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 2: Heterogeneity Analysis) ///
merge

test 1.treatment=2.treatment
test 1.treatment=3.treatment
test 2.treatment=3.treatment


***Data Broken Down By Past Behavior (Never Paid Before vs Paid Before)

regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start if never_paid_before==1, robust //all treatments are significantly different from the control group
outreg using Table2, se bdec(3) ctitle("",Never Paid) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 2: Heterogeneity Analysis) ///
merge

regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start if never_paid_before==0, robust //all treatments are significantly different from the control group
outreg using Table2, se bdec(3) ctitle("",Paid) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(F\r2_a\N) ///
summtitle(F statistics\Adjusted R-squared\Number of Observations) summdec(3 3 0) ///
title(Table 2: Heterogeneity Analysis) ///
merge

test 1.treatment=2.treatment
test 1.treatment=3.treatment
test 2.treatment=3.treatment


*****Comparing Table 4 Column 1 (males) with Table 4 Column 2 (females)

regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start if gender==1

est store a

regress paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start if gender==0

est store b

suest a b, robust

test [a_mean]1.treatment=[b_mean]1.treatment
test [a_mean]2.treatment=[b_mean]2.treatment
test [a_mean]3.treatment=[b_mean]3.treatment


************************************
****Multiple Hypotheses Testing*****
************************************


*** Multiple Sub-groups

*ssc install mhtexp //the procedure developed by List et al (2019)

gen subgroup=.
replace subgroup=1 if gender==1 & never_paid_before==0
replace subgroup=2 if gender==1 & never_paid_before==1
replace subgroup=3 if gender==0 & never_paid_before==0
replace subgroup=4 if gender==0 & never_paid_before==1


*******************************************************************************************************************************
*******Footnote 13: Multiplicity adjusted p-values for paiwrise comparisons across three treatment arms and the control********
*******************************************************************************************************************************

mhtexp paid_experiment, treatment(treatment) combo("pairwise")

*************************************************************************
******Footnote 16: Heterogeneity analysis for 4 different sub-groups*****
*************************************************************************

mhtexp paid_experiment, treatment(treatment) subgroup(subgroup)


***************************************************************************************
****Footnote 17************************************************************************
***************************************************************************************

tab gender never_paid_before, chi2


su taxarrears_2018
su taxarrears_2018 if never_paid_before==0
su taxarrears_2018 if never_paid_before==1


***************************************************************
******Conclusion***********************************************
***************************************************************


su taxarrears_2018
gen average_tax=r(mean)
bysort treatment: gen Taxpayer_Number=_N

*****In the paper

gen per_capita_benefitb=coeff_welfbr*average_tax
gen total_benefitb=per_capita_benefitb*Taxpayer_Number
cibar total_benefitb, over(treatment) bargap(10) barlabel(on)



***************************************************
************SURVIVAL ANALYSIS**********************
***************************************************

**2019 reminders sent
**reminders are sent on Sep 17, 20
**Sep 23, 26
**Sep 29, Oct 3
**Oct 8, Oct 11

gen day_before_exp_start=mdy(9,16,2019) //we assume the start data September 16 (i.e., September 16 is the time zero) 

gen days_survival=date_paid2018-day_before_exp_start
replace days_survival=experiment_end-day_before_exp_start if days_survival==. 

stset days_survival, failure(paid_experiment==1)
stdescribe //check whether the data is correctly set for the survival analysis

sts graph, by(treatment) xline(1) xline(4) xline(7) xline(10) xline(13) xline(17) xline(22) xline(25) ci //Kaplan-Meier curve by treatments
//the rest of the graph is edited manually

***********************************************
****** Probit Regressions: Robustness Check****
***********************************************

probit paid_experiment i.treatment, robust //all treatments are significantly different from the control group
margins, dydx(*) atmeans
outreg using TableB1, marginal se bdec(3) ctitle(Probit,1) drop(0b.treatment) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(chi2\r2_p\N) ///
summtitle(Wald Chi-squared\Pseudo R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B.1: Treatment Effects Analysis)

probit paid_experiment i.treatment Age gender taxarrears_2018 Months_paying_taxes_by_start, robust //all treatments are significantly different from the control group
margins, dydx(*) atmeans
outreg using TableB1, marginal se bdec(3) ctitle("",2) drop(0b.treatment) replace ///
starlevels(10 5 1) sigsymbols(*,**,***) summstat(chi2\r2_p\N) ///
summtitle(Wald Chi-squared\Pseudo R-squared\Number of Observations) summdec(3 3 0) ///
title(Table B.1: Treatment Effects Analysis) ///
merge

